===================================
Imperavi Redactor for Django admin
===================================

**Imperavi Redactor (WYSIWYG editor) integration app for Django admin**.

http://imperavi.com/redactor/

License
=======

Imperavi Redactor is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.

For commercial use please buy license here: http://redactorjs.com/download/ or use earlier version.


Documentation
=============

See `Django Suit documentation <http://django-suit.readthedocs.org/en/develop/wysiwyg.html>`_ on WYSIWYG editors.


Build Status
============

Django Suit Redactor app uses Travis CI to perform tests on different Django and Python versions.

.. |master| image:: https://travis-ci.org/darklow/django-suit-redactor.png?branch=master
   :alt: Build Status - master branch
   :target: http://travis-ci.org/darklow/django-suit-redactor

|master|
